@@ -35,7 +35,7 @@ class Selenium(Scraper):
         window_size = window['size'] if 'size' in window else []
 
         if len(window_size) == 0:
-            options.add_argument('start-maximized')
+            options.add_argument('--start-maximized')
 
         if headless is True:
             options.add_argument('headless')
